@@ -1,7 +1,7 @@
 from urllib import request as r
 from pathlib import Path
+import shutil as sh
 import subprocess
-import shutil
 import sys
 import os
 
@@ -21,7 +21,9 @@ if portable:
 try:
     import prettygit
     sys.exit()
-except ImportError:
+except ImportError as error_text:
+    # print(error_text)
+
     def run(
         command: str
     ) -> str:
@@ -30,6 +32,7 @@ except ImportError:
         )[-1]
 
     downloading_progress = 0
+
     def progress(
         block_num,
         block_size,
@@ -98,16 +101,24 @@ except ImportError:
 
     if portable:
         os.system(f'{pip} install {proj_name} -t {proj_path} --cache-dir {pip_cache_path}')
-        shutil.rmtree(
+        sh.rmtree(
             pip_cache_path,
             ignore_errors=True
         )
     else:
         os.system(f'{pip} install {proj_name}')
 
-    command = f'{sys.executable} {Path(__file__)}'
-    if portable:
-        command += ' portable'
+    for file_name in os.listdir(proj_path):
+        if (
+            len(file_name) > 10
+        ) and (
+            file_name[-10:] == '.dist-info'
+        ):
+            sh.rmtree(
+                f'{proj_path}/{file_name}',
+                ignore_errors=True,
+            )
+
     os.system(
-        command
+        sys.executable + " ".join(sys.path)
     )
